summaryrefslogtreecommitdiff
path: root/xmloff/inc/xmloff/SchXMLImportHelper.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'xmloff/inc/xmloff/SchXMLImportHelper.hxx')
-rw-r--r--xmloff/inc/xmloff/SchXMLImportHelper.hxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/xmloff/inc/xmloff/SchXMLImportHelper.hxx b/xmloff/inc/xmloff/SchXMLImportHelper.hxx
index d15b19ee5d38..a618d363137f 100644
--- a/xmloff/inc/xmloff/SchXMLImportHelper.hxx
+++ b/xmloff/inc/xmloff/SchXMLImportHelper.hxx
@@ -132,9 +132,9 @@ public:
static sal_uInt16 GetChartFamilyID() { return XML_STYLE_FAMILY_SCH_CHART_ID; }
/** @param bPushLastChartType If </FALSE>, in case a new chart type has to
be added (because it does not exist yet), it is appended at the
- end of the chart-type container. When </TRUE>, a new chart type
+ end of the chart-type container. When </sal_True>, a new chart type
is added at one position before the last one, i.e. the formerly
last chart type is pushed back, so that it remains the last one.
@@ -132,9 +132,9 @@ public:
static sal_uInt16 GetChartFamilyID() { return XML_STYLE_FAMILY_SCH_CHART_ID; }
- /** @param bPushLastChartType If </FALSE>, in case a new chart type has to
+ /** @param bPushLastChartType If </sal_False>, in case a new chart type has to
be added (because it does not exist yet), it is appended at the